@@ -1,4 +1,4 @@
-/* $Id: xfce-miscutils.c 21064 2006-04-18 19:35:58Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
@@ -45,7 +45,7 @@
 #endif
 #ifdef HAVE_STAD_ARG_H
 #include <stdarg.h>
-#elif HAVE_VARARGS_H
+#elif defined (HAVE_VARARGS_H)
 #include <varargs.h>
 #endif
 #include <stdio.h>
@@ -119,11 +119,11 @@ internal_initialize(void)
 static gchar*
 internal_get_file_r (const gchar *dir,
                      gchar       *buffer,
-                     size_t       len,
+                     gsize        len,
                      const gchar *format,
                      va_list      ap)
 {
-  size_t n;
+  gsize n;
 
   g_return_val_if_fail(buffer != NULL, NULL);
   g_return_val_if_fail(format != NULL, NULL);
@@ -135,7 +135,7 @@ internal_get_file_r (const gchar *dir,
   if ((n = g_strlcat(buffer, G_DIR_SEPARATOR_S, len)) >= len)
     return NULL;
 
-  if (g_vsnprintf(buffer + n, len - n, format, ap) >= len - n)
+  if ((gsize) g_vsnprintf(buffer + n, len - n, format, ap) >= len - n)
     return NULL;
 
   return buffer;
