@@ -1,4 +1,4 @@
-/* $Id: xfce-rc-simple.c 24966 2007-02-13 10:16:28Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2003-2007 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
@@ -73,7 +73,7 @@ static gboolean simple_parse_line (gchar        *line,
                                    gchar       **value,
                                    gchar       **locale);
 static gchar*   simple_escape     (gchar        *buffer,
-                                   gsize         size,
+                                   gssize        size,
                                    const gchar  *string);
 static gboolean simple_write      (XfceRcSimple *simple,
                                    const gchar  *filename);
@@ -431,7 +431,7 @@ simple_parse_line (gchar  *line,
 
 
 static gchar*
-simple_escape (gchar *buffer, gsize size, const gchar *string)
+simple_escape (gchar *buffer, gssize size, const gchar *string)
 {
   const gchar *s;
   gchar       *p;
